@@ -1,15 +1,14 @@
 #' @title Histogram for distribution of a numeric variable
 #' @name gghistostats
-#' @description Histogram with statistical details from one-sample test included
-#'   in the plot as a subtitle.
+#'
+#' @description
+#'
+#' \Sexpr[results=rd, stage=render]{rlang:::lifecycle("maturing")}
+#'
+#' Histogram with statistical details from one-sample test included in the plot
+#' as a subtitle.
 #'
 #' @param ... Currently ignored.
-#' @param bar.measure Character describing what value needs to be represented as
-#'   height in the bar chart. This can either be `"count"`, which shows number
-#'   of points in bin, or `"density"`, which density of points in bin, scaled to
-#'   integrate to 1, or "`proportion`", which shows relative frequencies of
-#'   observations in each bin, or "`mix`", which shows *both* count and
-#'   proportion in the same plot.
 #' @param normal.curve A logical value that decides whether to super-impose a
 #'   normal curve using `stats::dnorm(mean(x), sd(x))`. Default is `FALSE`.
 #' @param normal.curve.args A list of additional aesthetic arguments to be
@@ -34,15 +33,14 @@
 #' @importFrom dplyr group_by n arrange
 #' @importFrom rlang enquo as_name !!
 #' @importFrom stats dnorm
-#' @importFrom statsExpressions expr_t_onesample bf_ttest
+#' @importFrom statsExpressions expr_t_onesample
 #'
 #' @references
 #' \url{https://indrajeetpatil.github.io/ggstatsplot/articles/web_only/gghistostats.html}
 #'
 #' @examples
 #' \donttest{
-#' # most basic function call with the defaults
-#' # this is the **only** function where data argument can be `NULL`
+#' # most basic function
 #' ggstatsplot::gghistostats(
 #'   data = ToothGrowth,
 #'   x = len,
@@ -54,9 +52,8 @@
 #' ggstatsplot::gghistostats(
 #'   data = iris,
 #'   x = Sepal.Length,
-#'   bar.measure = "mix",
 #'   type = "p",
-#'   caption = substitute(paste(italic("Note"), ": Iris dataset by Fisher.")),
+#'   caption = substitute(paste(italic("Note"), ": Iris dataset by Anderson")),
 #'   bf.prior = 0.8,
 #'   test.value = 3,
 #'   test.value.line = TRUE,
@@ -70,7 +67,6 @@
 gghistostats <- function(data,
                          x,
                          binwidth = NULL,
-                         bar.measure = "count",
                          xlab = NULL,
                          title = NULL,
                          subtitle = NULL,
@@ -82,21 +78,18 @@ gghistostats <- function(data,
                          effsize.type = "g",
                          conf.level = 0.95,
                          nboot = 100,
+                         tr = 0.1,
                          k = 2L,
                          ggtheme = ggplot2::theme_bw(),
                          ggstatsplot.layer = TRUE,
                          bar.fill = "grey50",
                          results.subtitle = TRUE,
-                         test.k = 0,
-                         test.value.line = FALSE,
-                         test.value.line.args = list(size = 1),
-                         test.value.label.args = list(size = 3),
-                         centrality.parameter = "mean",
+                         centrality.plotting = TRUE,
                          centrality.k = 2,
                          centrality.line.args = list(size = 1, color = "blue"),
                          centrality.label.args = list(color = "blue", size = 3),
                          normal.curve = FALSE,
-                         normal.curve.args = list(size = 3),
+                         normal.curve.args = list(size = 2),
                          ggplot.component = NULL,
                          output = "plot",
                          ...) {
@@ -115,8 +108,7 @@ gghistostats <- function(data,
   # if dataframe is provided
   df <-
     dplyr::select(.data = data, {{ x }}) %>%
-    tidyr::drop_na(data = .) %>%
-    as_tibble(x = .)
+    tidyr::drop_na(.)
 
   # column as a vector
   x_vec <- df %>% dplyr::pull({{ x }})
@@ -138,81 +130,29 @@ gghistostats <- function(data,
         effsize.type = effsize.type,
         conf.level = conf.level,
         nboot = nboot,
+        tr = tr,
         k = k
       )
 
     # preparing the BF message
-    if (isTRUE(bf.message)) {
-      bf.caption.text <-
-        statsExpressions::bf_ttest(
+    if (type == "parametric" && isTRUE(bf.message)) {
+      caption <-
+        statsExpressions::expr_t_onesample(
           data = df,
           x = {{ x }},
+          type = "bayes",
           test.value = test.value,
           bf.prior = bf.prior,
           top.text = caption,
           output = "expression",
           k = k
         )
-
-      # if bayes factor message needs to be displayed
-      if (type == "parametric" && isTRUE(bf.message)) caption <- bf.caption.text
     }
   }
 
   # return early if anything other than plot
   if (output != "plot") {
-    return(switch(EXPR = output, "caption" = caption, subtitle))
-  }
-
-  # ======================= normal curve ===================================
-
-  # preparing the arguments needed for displaying a normal curve on the plot
-
-  # only counts
-  if (bar.measure %in% c("counts", "n", "count", "N")) {
-    .mapping <- ggplot2::aes(y = ..count.., fill = ..count..)
-    ylab_add <- NULL
-    .f_stat <- function(x, mean, sd, n, bw) stats::dnorm(x, mean, sd) * n * bw
-    args <- list(mean = mean(x_vec), sd = sd(x_vec), n = length(x_vec), bw = binwidth)
-  }
-
-  # only proportion
-  if (bar.measure %in% c("percentage", "perc", "proportion", "prop", "%")) {
-    .mapping <- ggplot2::aes(y = ..count.. / sum(..count..), fill = ..count.. / sum(..count..))
-    ylab_add <-
-      list(
-        ggplot2::scale_y_continuous(labels = function(x) paste0(x * 100, "%")),
-        ggplot2::ylab("proportion")
-      )
-    .f_stat <- function(x, mean, sd, n, bw) stats::dnorm(x, mean, sd) * bw
-    args <- list(mean = mean(x_vec), sd = sd(x_vec), n = length(x_vec), bw = binwidth)
-  }
-
-  # only density
-  if (bar.measure == "density") {
-    .mapping <- ggplot2::aes(y = ..density.., fill = ..density..)
-    ylab_add <- NULL
-    .f_stat <- stats::dnorm
-    args <- list(mean = mean(x_vec), sd = sd(x_vec))
-  }
-
-  # all things combined
-  if (bar.measure %in% c("both", "mix", "all", "everything")) {
-    .mapping <- ggplot2::aes(y = ..count.., fill = ..count..)
-    ylab_add <-
-      list(
-        ggplot2::scale_y_continuous(
-          sec.axis = ggplot2::sec_axis(
-            trans = ~ . / nrow(df),
-            labels = function(x) paste0(x * 100, "%"),
-            name = "proportion"
-          )
-        ),
-        ggplot2::ylab("count"),
-        ggplot2::guides(fill = FALSE)
-      )
-    .f_stat <- function(x, mean, sd, n, bw) stats::dnorm(x, mean, sd) * n * bw
-    args <- list(mean = mean(x_vec), sd = sd(x_vec), n = length(x_vec), bw = binwidth)
+    return(switch(output, "caption" = caption, subtitle))
   }
 
   # ============================= plot ====================================
@@ -226,18 +166,25 @@ gghistostats <- function(data,
       alpha = 0.7,
       binwidth = binwidth,
       na.rm = TRUE,
-      mapping = .mapping
+      mapping = ggplot2::aes(y = ..count.., fill = ..count..)
     ) +
-    ylab_add
+    ggplot2::scale_y_continuous(
+      sec.axis = ggplot2::sec_axis(
+        trans = ~ . / nrow(df),
+        labels = function(x) paste0(x * 100, "%"),
+        name = "proportion"
+      )
+    ) +
+    ggplot2::guides(fill = FALSE)
 
   # if normal curve overlay  needs to be displayed
   if (isTRUE(normal.curve)) {
     plot <- plot +
       rlang::exec(
         .f = ggplot2::stat_function,
-        fun = .f_stat,
+        fun = function(x, mean, sd, n, bw) stats::dnorm(x, mean, sd) * n * bw,
         na.rm = TRUE,
-        args = args,
+        args = list(mean = mean(x_vec), sd = sd(x_vec), n = length(x_vec), bw = binwidth),
         !!!normal.curve.args
       )
   }
@@ -247,32 +194,27 @@ gghistostats <- function(data,
     theme_ggstatsplot(ggtheme = ggtheme, ggstatsplot.layer = ggstatsplot.layer) +
     ggplot2::labs(
       x = xlab,
+      y = "count",
       title = title,
       subtitle = subtitle,
       caption = caption
     )
 
-  # ====================== centrality line and label ========================
-
-  # computing statistics needed for displaying labels
-  y_label_pos <- median(ggplot2::layer_scales(plot)$y$range$range, na.rm = TRUE)
+  # ---------------- centrality tagging -------------------------------------
 
   # using custom function for adding labels
-  plot <-
-    histo_labeller(
-      plot = plot,
-      x = x_vec,
-      y.label.position = y_label_pos,
-      test.value = test.value,
-      test.k = test.k,
-      test.value.line = test.value.line,
-      test.value.line.args = test.value.line.args,
-      test.value.label.args = test.value.label.args,
-      centrality.parameter = centrality.parameter,
-      centrality.k = centrality.k,
-      centrality.line.args = centrality.line.args,
-      centrality.label.args = centrality.label.args
-    )
+  if (isTRUE(centrality.plotting)) {
+    plot <-
+      histo_labeller(
+        plot = plot,
+        x = x_vec,
+        type = type,
+        tr = tr,
+        centrality.k = centrality.k,
+        centrality.line.args = centrality.line.args,
+        centrality.label.args = centrality.label.args
+      )
+  }
 
   # ---------------- adding ggplot component ---------------------------------
 
