@@ -1,7 +1,12 @@
 #' @title Pie charts with statistical tests
 #' @name ggpiestats
-#' @description Pie charts for categorical data with statistical details
-#'   included in the plot as a subtitle.
+#'
+#' @description
+#'
+#' \Sexpr[results=rd, stage=render]{rlang:::lifecycle("maturing")}
+#'
+#' Pie charts for categorical data with statistical details included in the plot
+#' as a subtitle.
 #'
 #' @param x The variable to use as the **rows** in the contingency table. Please
 #'   note that if there are empty factor levels in your variable, they will be
@@ -26,7 +31,6 @@
 #'   This can be helpful in case the labels are overlapping.
 #' @param legend.title Title text for the legend.
 #' @inheritParams ggbetweenstats
-#' @inheritParams tidyBF::bf_contingency_tab
 #' @inheritParams statsExpressions::expr_contingency_tab
 #' @inheritParams theme_ggstatsplot
 #' @inheritParams gghistostats
@@ -36,12 +40,12 @@
 #'
 #' @import ggplot2
 #'
-#' @importFrom dplyr select mutate vars pull
-#' @importFrom rlang !! enquo quo_name as_name ensym
+#' @importFrom dplyr select mutate vars pull across everything
+#' @importFrom rlang !! enquo as_name ensym
 #' @importFrom ggrepel geom_label_repel
 #' @importFrom paletteer scale_fill_paletteer_d
 #' @importFrom tidyr uncount drop_na
-#' @importFrom statsExpressions bf_contingency_tab expr_contingency_tab
+#' @importFrom statsExpressions expr_contingency_tab
 #'
 #' @references
 #' \url{https://indrajeetpatil.github.io/ggstatsplot/articles/web_only/ggpiestats.html}
@@ -111,22 +115,20 @@ ggpiestats <- function(data,
 
   # creating a dataframe
   data %<>%
-    dplyr::select(.data = ., {{ x }}, {{ y }}, .counts = {{ counts }}) %>%
-    tidyr::drop_na(data = .) %>%
-    as_tibble(x = .)
+    dplyr::select({{ x }}, {{ y }}, .counts = {{ counts }}) %>%
+    tidyr::drop_na(.)
 
   # untable the dataframe based on the count for each observation
   if (".counts" %in% names(data)) data %<>% tidyr::uncount(data = ., weights = .counts)
 
   # x and y need to be a factor; also drop the unused levels of the factors
+  data %<>% dplyr::mutate(dplyr::across(dplyr::everything(), ~ droplevels(as.factor(.x))))
 
   # x
-  data %<>% dplyr::mutate(.data = ., {{ x }} := droplevels(as.factor({{ x }})))
   x_levels <- nlevels(data %>% dplyr::pull({{ x }}))[[1]]
 
   # y
   if (!rlang::quo_is_null(rlang::enquo(y))) {
-    data %<>% dplyr::mutate(.data = ., {{ y }} := droplevels(as.factor({{ y }})))
     y_levels <- nlevels(data %>% dplyr::pull({{ y }}))[[1]]
 
     # TO DO: until one-way table is supported by `BayesFactor`
@@ -161,10 +163,11 @@ ggpiestats <- function(data,
     if (isTRUE(bf.message) && !is.null(subtitle)) {
       caption <-
         tryCatch(
-          expr = bf_contingency_tab(
+          expr = statsExpressions::expr_contingency_tab(
             data = data,
             x = {{ x }},
             y = {{ y }},
+            type = "bayes",
             sampling.plan = sampling.plan,
             fixed.margin = fixed.margin,
             prior.concentration = prior.concentration,
