@@ -4,21 +4,17 @@ utils::globalVariables(
   names = c(
     ".",
     "..count..",
-    "..density..",
     "N",
     "conf.high",
     "conf.low",
     "counts",
     "df.error",
-    "df1",
-    "df2",
     "estimate",
     "group1",
     "group2",
     "isanoutlier",
     "label",
     "median",
-    "n_obs",
     "p.value",
     "parameter",
     "perc",
@@ -31,7 +27,13 @@ utils::globalVariables(
     "df",
     ".label",
     ".counts",
-    ".p.label"
+    ".p.label",
+    "trimmed.mean",
+    "group",
+    "r.method",
+    "r.method.text",
+    ".temp",
+    "var"
   ),
   package = "ggstatsplot",
   add = FALSE
