@@ -30,14 +30,14 @@ ggcoefstats_label_maker <- function(tidy_df,
       dplyr::mutate(
         label = paste0(
           "list(~widehat(italic(beta))==",
-          specify_decimal_p(x = estimate, k = k),
+          format_num(estimate, k = k),
           ", ~italic(t)",
           "(",
-          specify_decimal_p(x = df.error, k = 0L),
+          format_num(df.error, k = 0L),
           ")==",
-          specify_decimal_p(x = statistic, k = k),
+          format_num(statistic, k = k),
           ", ~italic(p)=='",
-          specify_decimal_p(x = p.value, k = k, p.value = TRUE),
+          format_num(p.value, k = k, p.value = TRUE),
           "')"
         )
       )
@@ -51,11 +51,11 @@ ggcoefstats_label_maker <- function(tidy_df,
       dplyr::mutate(
         label = paste0(
           "list(~widehat(italic(beta))==",
-          specify_decimal_p(x = estimate, k = k),
+          format_num(estimate, k = k),
           ", ~italic(z)==",
-          specify_decimal_p(x = statistic, k = k),
+          format_num(statistic, k = k),
           ", ~italic(p)=='",
-          specify_decimal_p(x = p.value, k = k, p.value = TRUE),
+          format_num(p.value, k = k, p.value = TRUE),
           "')"
         )
       )
@@ -65,15 +65,21 @@ ggcoefstats_label_maker <- function(tidy_df,
 
   # if the statistic is chi^2-value
   if (statistic == "c") {
+    # if not present, add NA column for dfs
+    if (!"df.error" %in% names(tidy_df)) tidy_df %<>% dplyr::mutate(df.error = Inf)
+
     tidy_df %<>%
       dplyr::mutate(
         label = paste0(
           "list(~widehat(italic(beta))==",
-          specify_decimal_p(x = estimate, k = k),
-          ", ~italic(chi)^2==",
-          specify_decimal_p(x = statistic, k = k),
+          format_num(estimate, k = k),
+          ", ~italic(chi)^2~",
+          "(",
+          format_num(df.error, k = 0L),
+          ")==",
+          format_num(statistic, k = k),
           ", ~italic(p)=='",
-          specify_decimal_p(x = p.value, k = k, p.value = TRUE),
+          format_num(p.value, k = k, p.value = TRUE),
           "')"
         )
       )
@@ -92,17 +98,17 @@ ggcoefstats_label_maker <- function(tidy_df,
         label = paste0(
           "list(~italic(F)",
           "(",
-          df1,
+          df,
           "*\",\"*",
-          df2,
+          df.error,
           ")==",
-          specify_decimal_p(x = statistic, k = k),
+          format_num(statistic, k = k),
           ", ~italic(p)=='",
-          specify_decimal_p(x = p.value, k = k, p.value = TRUE),
+          format_num(p.value, k = k, p.value = TRUE),
           "', ~",
           effsize.text,
           "==",
-          specify_decimal_p(x = estimate, k = k),
+          format_num(estimate, k = k),
           ")"
         )
       )
