@@ -48,10 +48,14 @@ common_theme_element <-
 #' @export
 
 theme_corrmat <- function() {
-  ggplot2::theme() + common_theme_element
+  ggplot2::theme(
+    panel.grid.major = ggplot2::element_blank(),
+    panel.grid.minor = ggplot2::element_blank()
+  ) +
+    common_theme_element +
+    ggplot2::theme(legend.title = ggplot2::element_text(size = 15))
 }
 
-
 #' @rdname theme_ggstatsplot
 #' @aliases theme_ggstatsplot
 #' @export
