@@ -1,9 +1,9 @@
 # checking plot and parametric stats --------------------------------------
 
-testthat::test_that(
+test_that(
   desc = "checking gghistostats plot and parametric stats - data with NAs",
   code = {
-    testthat::skip_on_cran()
+    skip_on_cran()
 
     # creating the plot
     set.seed(123)
@@ -17,17 +17,14 @@ testthat::test_that(
         bar.fill = "orange",
         test.value = 150,
         bf.prior = 0.9,
-        test.k = 0,
-        centrality.k = 0,
-        test.value.line = TRUE,
-        messages = TRUE
+        centrality.k = 0
       )
 
     # build the plot
     pb <- ggplot2::ggplot_build(p)
 
     # checking geom data
-    testthat::expect_equal(
+    expect_equal(
       pb$data[[1]],
       structure(
         list(
@@ -161,25 +158,8 @@ testthat::test_that(
       )
     )
 
-    testthat::expect_equal(
+    expect_equal(
       pb$data[[2]],
-      structure(
-        list(
-          xintercept = 150,
-          PANEL = structure(1L, .Label = "1", class = "factor"),
-          group = structure(-1L, n = 1L),
-          colour = "black",
-          size = 1,
-          linetype = "dashed",
-          alpha = NA
-        ),
-        row.names = c(NA, -1L),
-        class = "data.frame"
-      )
-    )
-
-    testthat::expect_equal(
-      pb$data[[4]],
       structure(
         list(
           xintercept = 174.358024691358,
@@ -196,30 +176,20 @@ testthat::test_that(
     )
 
     # checking different data layers
-    testthat::expect_equal(length(pb$data), 5L)
-    testthat::expect_equal(dim(pb$data[[1]]), c(11L, 18L))
-    testthat::expect_equal(dim(pb$data[[2]]), c(1L, 7L))
-    testthat::expect_equal(dim(pb$data[[3]]), c(81L, 15L))
-    testthat::expect_equal(dim(pb$data[[4]]), c(1L, 7L))
-    testthat::expect_equal(dim(pb$data[[5]]), c(81L, 15L))
+    expect_equal(length(pb$data), 3L)
+    expect_equal(dim(pb$data[[1]]), c(11L, 18L))
+    expect_equal(dim(pb$data[[2]]), c(1L, 7L))
+    expect_equal(dim(pb$data[[3]]), c(81L, 15L))
 
-    testthat::expect_equal(
+    expect_equal(
       class(pb$data[[3]]$label[[1]]),
-      "call"
+      "character"
     )
-    testthat::expect_equal(
-      class(pb$data[[5]]$label[[1]]),
-      "call"
-    )
-    testthat::expect_equal(
+    expect_identical(
       pb$data[[3]]$label[[1]],
-      ggplot2::expr("test" == "150")
+      "list(~widehat(mu)[mean]=='174')"
     )
-    testthat::expect_equal(
-      pb$data[[5]]$label[[1]],
-      ggplot2::expr("mean" == "174")
-    )
-    testthat::expect_null(pb$layout$panel_params[[1]]$y.sec.labels, NULL)
+    expect_null(pb$layout$panel_params[[1]]$y.sec.labels, NULL)
 
     # checking subtitle
     set.seed(123)
@@ -228,37 +198,35 @@ testthat::test_that(
         data = dplyr::starwars,
         x = height,
         type = "p",
-        test.value = 150,
-        messages = FALSE
+        test.value = 150
       )
 
     # checking caption
     set.seed(123)
     p_cap <-
-      statsExpressions::bf_ttest(
+      statsExpressions::expr_t_onesample(
         data = dplyr::starwars,
         x = height,
-        type = "p",
+        type = "bf",
         test.value = 150,
-        messages = FALSE,
         bf.prior = 0.9,
         output = "caption"
       )
 
     # testing overall call
-    testthat::expect_identical(pb$plot$labels$subtitle, p_subtitle)
-    testthat::expect_identical(pb$plot$labels$title, "starwars: character heights")
-    testthat::expect_identical(pb$plot$labels$x, "character height")
-    testthat::expect_identical(pb$plot$labels$caption, p_cap)
+    expect_identical(pb$plot$labels$subtitle, p_subtitle)
+    expect_identical(pb$plot$labels$title, "starwars: character heights")
+    expect_identical(pb$plot$labels$x, "character height")
+    expect_identical(pb$plot$labels$caption, p_cap)
   }
 )
 
 # checking plot and non-parametric stats -----------------------------------
 
-testthat::test_that(
+test_that(
   desc = "checking gghistostats and non-parametric stats - data without NAs",
   code = {
-    testthat::skip_on_cran()
+    skip_on_cran()
 
     # creating the plot
     set.seed(123)
@@ -269,69 +237,57 @@ testthat::test_that(
         xlab = "city miles per gallon",
         title = "fuel economy",
         caption = substitute(paste(italic("source"), ": government website")),
-        centrality.parameter = "median",
-        bar.measure = "mix",
         binwidth = 5,
         test.value = 20,
         k = 3,
         type = "np",
-        test.k = 2,
         centrality.k = 2,
-        test.value.line = TRUE,
-        results.subtitle = FALSE,
-        messages = FALSE
+        results.subtitle = FALSE
       )
 
     # build the plot
     pb <- ggplot2::ggplot_build(p)
 
     # checking different data layers
-    testthat::expect_equal(length(pb$data), 5L)
-    testthat::expect_equal(nrow(pb$data[[1]]), 6L)
-    testthat::expect_equal(
-      pb$data[[4]]$xintercept,
+    expect_equal(length(pb$data), 3L)
+    expect_equal(nrow(pb$data[[1]]), 6L)
+    expect_equal(
+      pb$data[[2]]$xintercept,
       median(ggplot2::mpg$cty, na.rm = TRUE),
       tolerance = 0.001
     )
-    testthat::expect_equal(pb$data[[2]]$xintercept,
-      20.000,
+    expect_equal(pb$data[[2]]$xintercept,
+      17.000,
       tolerance = 0.001
     )
-    testthat::expect_equal(
+    expect_identical(
       pb$data[[3]]$label[[1]],
-      ggplot2::expr("test" == "20.00")
+      "list(~widehat(mu)[median]=='17.00')"
     )
-    testthat::expect_equal(
-      pb$data[[5]]$label[[1]],
-      ggplot2::expr("median" == "17.00")
-    )
-    testthat::expect_equal(pb$data[[1]]$y[1], 33L)
-    testthat::expect_equal(pb$data[[1]]$y[6], 2L)
-    testthat::expect_equal(pb$data[[1]]$x[1], 10L)
-    testthat::expect_equal(pb$data[[1]]$x[6], 35L)
-    testthat::expect_equal(pb$data[[1]]$xmin[1], 7.5, tolerance = 0.001)
-    testthat::expect_equal(pb$data[[1]]$xmax[1], 12.5, tolerance = 0.001)
-    testthat::expect_equal(pb$data[[1]]$xmin[6], 32.5, tolerance = 0.001)
-    testthat::expect_equal(pb$data[[1]]$xmax[6], 37.5, tolerance = 0.001)
+    expect_equal(pb$data[[1]]$y[1], 33L)
+    expect_equal(pb$data[[1]]$y[6], 2L)
+    expect_equal(pb$data[[1]]$x[1], 10L)
+    expect_equal(pb$data[[1]]$x[6], 35L)
+    expect_equal(pb$data[[1]]$xmin[1], 7.5, tolerance = 0.001)
+    expect_equal(pb$data[[1]]$xmax[1], 12.5, tolerance = 0.001)
+    expect_equal(pb$data[[1]]$xmin[6], 32.5, tolerance = 0.001)
+    expect_equal(pb$data[[1]]$xmax[6], 37.5, tolerance = 0.001)
 
     # checking panel parameters
-    testthat::expect_equal(pb$layout$panel_params[[1]]$x$limits, c(7.5, 37.5))
-    testthat::expect_identical(
+    expect_equal(pb$layout$panel_params[[1]]$x$limits, c(7.5, 37.5))
+    expect_identical(
       pb$layout$panel_params[[1]]$x$breaks,
       c(NA, 10, 20, 30, NA)
     )
-    testthat::expect_identical(
+    expect_identical(
       pb$layout$panel_params[[1]]$y$breaks,
       c(0, 25, 50, 75, 100)
     )
-    testthat::expect_equal(
+    expect_equal(
       pb$layout$panel_params[[1]]$y.sec$break_info,
       list(
         range = c(-0.0211538461538462, 0.444230769230769),
-        labels = c(
-          "0%",
-          "10%", "20%", "30%", "40%"
-        ),
+        labels = c("0%", "10%", "20%", "30%", "40%"),
         major = c(
           0.045, 0.26, 0.475, 0.69,
           0.905
@@ -367,11 +323,11 @@ testthat::test_that(
     )
 
     # testing labels
-    testthat::expect_identical(p$labels$subtitle, NULL)
-    testthat::expect_identical(p$labels$title, "fuel economy")
-    testthat::expect_identical(p$labels$x, "city miles per gallon")
-    testthat::expect_identical(p$labels$y, "count")
-    testthat::expect_identical(
+    expect_identical(p$labels$subtitle, NULL)
+    expect_identical(p$labels$title, "fuel economy")
+    expect_identical(p$labels$x, "city miles per gallon")
+    expect_identical(p$labels$y, "count")
+    expect_identical(
       p$labels$caption,
       ggplot2::expr(paste(
         italic("source"),
@@ -383,10 +339,10 @@ testthat::test_that(
 
 # checking robust stats and proportions -----------------------------------
 
-testthat::test_that(
+test_that(
   desc = "checking robust stats and proportions",
   code = {
-    testthat::skip_on_cran()
+    skip_on_cran()
 
     # creating the plot
     set.seed(123)
@@ -394,13 +350,9 @@ testthat::test_that(
       ggstatsplot::gghistostats(
         data = mtcars,
         x = wt,
-        bar.measure = "proportion",
         binwidth = 0.5,
         test.value = 2.5,
-        type = "r",
-        test.value.line = FALSE,
-        centrality.parameter = FALSE,
-        messages = FALSE
+        type = "r"
       ) +
       scale_x_continuous(limits = c(1, 6))
 
@@ -414,222 +366,190 @@ testthat::test_that(
         data = mtcars,
         x = wt,
         test.value = 2.5,
-        type = "r",
-        messages = FALSE
+        type = "r"
       )
 
     # testing labels
-    testthat::expect_identical(pb$plot$labels$subtitle, p_subtitle)
-    testthat::expect_null(pb$plot$labels$caption, NULL)
-    testthat::expect_identical(pb$plot$labels$y, "proportion")
+    expect_identical(pb$plot$labels$subtitle, p_subtitle)
+    expect_null(pb$plot$labels$caption, NULL)
+    expect_identical(pb$plot$labels$y, "count")
+
+    expect_identical(
+      pb$data[[3]]$label[[1]],
+      "list(~widehat(mu)[trimmed]=='3.15')"
+    )
 
     # checking different data layers
-    testthat::expect_equal(length(pb$data), 1L)
-    testthat::expect_equal(nrow(pb$data[[1]]), 11L)
-    testthat::expect_equal(
+    expect_equal(length(pb$data), 3L)
+    expect_equal(nrow(pb$data[[1]]), 11L)
+    expect_equal(
       pb$data[[1]]$y,
-      c(
-        0.00000,
-        0.06250,
-        0.12500,
-        0.09375,
-        0.21875,
-        0.28125,
-        0.12500,
-        0.00000,
-        0.03125,
-        0.06250,
-        0.00000
-      ),
+      c(0, 2, 4, 3, 7, 9, 4, 0, 1, 2, 0),
       tolerance = 0.001
     )
-    testthat::expect_equal(pb$data[[1]]$x,
+    expect_equal(
+      pb$data[[1]]$x,
       c(1.0, 1.5, 2.0, 2.5, 3.0, 3.5, 4.0, 4.5, 5.0, 5.5, 6.0),
       tolerance = 0.01
     )
   }
 )
 
-# checking bayes stats and density -----------------------------------
-
-testthat::test_that(
-  desc = "checking bayes stats and density",
-  code = {
-    testthat::skip_on_cran()
-
-    # creating the plot
-    set.seed(123)
-    p <-
-      suppressMessages(ggstatsplot::gghistostats(
-        data = morley,
-        x = Speed,
-        bar.measure = "density",
-        binwidth = 50,
-        test.value = 2.5,
-        type = "bf",
-        test.value.line = FALSE,
-        centrality.parameter = FALSE,
-        messages = FALSE
-      ))
-
-    # build the plot
-    pb <- ggplot2::ggplot_build(p)
-
-    # checking subtitle
-    set.seed(123)
-    p_subtitle <-
-      statsExpressions::expr_t_onesample(
-        data = morley,
-        x = Speed,
-        test.value = 2.5,
-        type = "bf",
-        messages = FALSE
-      )
-
-    # testing labels
-    testthat::expect_identical(p$labels$subtitle, p_subtitle)
-    testthat::expect_identical(p$labels$y, "density")
-
-    # checking different data layers
-    testthat::expect_equal(length(pb$data), 1L)
-    testthat::expect_equal(nrow(pb$data[[1]]), 10L)
-    testthat::expect_equal(pb$data[[1]]$y[1], 0.0002, tolerance = 0.001)
-    testthat::expect_equal(pb$data[[1]]$y[5], 0.0044, tolerance = 0.001)
-    testthat::expect_equal(pb$data[[1]]$x[1], 600, tolerance = 0.01)
-    testthat::expect_equal(pb$data[[1]]$x[5], 800, tolerance = 0.01)
-
-    # checking panel parameters
-    testthat::expect_equal(pb$layout$panel_params[[1]]$x.range,
-      c(550, 1100),
-      tolerance = 0.001
-    )
-  }
-)
-
 # checking if normal curve works -------------------------------------
 
-testthat::test_that(
-  desc = "checking with default binwidth",
+test_that(
+  desc = "checking if normal curve work",
   code = {
-    testthat::skip_on_cran()
+    skip_on_cran()
 
-    # creating a subset of the dataset
+    # plot
     set.seed(123)
-    dat1 <- dplyr::sample_frac(tbl = ggplot2::txhousing, size = 0.05)
-    dat2 <- ggplot2::msleep
-
-    # plot-1
     p1 <-
       ggstatsplot::gghistostats(
-        data = dat1,
-        x = sales,
-        results.subtitle = FALSE,
-        normal.curve = TRUE,
-        bar.measure = "count",
-        messages = FALSE
-      )
-
-    # plot-2
-    p2 <-
-      ggstatsplot::gghistostats(
-        data = dat1,
-        x = sales,
-        results.subtitle = FALSE,
-        normal.curve = TRUE,
-        binwidth = 100,
-        bar.measure = "proportion",
-        messages = FALSE
-      )
-
-    # plot-3
-    p3 <-
-      ggstatsplot::gghistostats(
-        data = dat2,
-        x = brainwt,
+        data = ggplot2::msleep,
+        x = awake,
+        binwidth = 1,
         results.subtitle = FALSE,
         normal.curve = TRUE,
         normal.curve.args =
           list(
             color = "red",
             size = 0.8
-          ),
-        bar.measure = "mix",
-        messages = FALSE
-      )
-
-    # plot-4
-    p4 <-
-      ggstatsplot::gghistostats(
-        data = dat2,
-        x = brainwt,
-        results.subtitle = FALSE,
-        normal.curve = TRUE,
-        bar.measure = "density",
-        binwidth = 0.05,
-        normal.curve.args =
-          list(
-            color = "black",
-            linetype = "dashed",
-            size = 1
-          ),
-        messages = FALSE
-      )
-
-    # plot-5
-    p5 <-
-      ggstatsplot::gghistostats(
-        data = dat2,
-        x = brainwt,
-        results.subtitle = FALSE,
-        normal.curve = FALSE,
-        messages = FALSE
+          )
       )
 
     # build plots
     pb1 <- ggplot2::ggplot_build(p1)
-    pb2 <- ggplot2::ggplot_build(p2)
-    pb3 <- ggplot2::ggplot_build(p3)
-    pb4 <- ggplot2::ggplot_build(p4)
-    pb5 <- ggplot2::ggplot_build(p5)
 
     # check data layers
-    testthat::expect_equal(length(pb1$data), 4L)
-    testthat::expect_equal(length(pb2$data), 4L)
-    testthat::expect_equal(length(pb3$data), 4L)
-    testthat::expect_equal(length(pb4$data), 4L)
-    testthat::expect_equal(length(pb5$data), 3L)
+    expect_equal(length(pb1$data), 4L)
 
-    # check aesthetic of the respective layer
-    testthat::expect_equal(dim(pb1$data[[2]]), c(101L, 8L))
-    testthat::expect_identical(unique(pb1$data[[2]]$colour), "black")
-    testthat::expect_equal(unique(pb1$data[[2]]$linetype), 1)
-    testthat::expect_equal(unique(pb1$data[[2]]$size), 3)
-    testthat::expect_identical(unique(pb3$data[[2]]$colour), "red")
-    testthat::expect_equal(unique(pb3$data[[2]]$size), 0.8)
-    testthat::expect_identical(unique(pb4$data[[2]]$linetype), "dashed")
+    # check individual layers
+    expect_equal(
+      pb1$data[[1]],
+      structure(list(fill = c(
+        "grey50", "grey50", "grey50", "grey50",
+        "grey50", "grey50", "grey50", "grey50", "grey50", "grey50", "grey50",
+        "grey50", "grey50", "grey50", "grey50", "grey50", "grey50", "grey50",
+        "grey50"
+      ), y = c(
+        2, 1, 2, 3, 4, 4, 7, 7, 2, 6, 12, 8, 5, 1, 4,
+        4, 5, 5, 1
+      ), count = c(
+        2, 1, 2, 3, 4, 4, 7, 7, 2, 6, 12, 8, 5,
+        1, 4, 4, 5, 5, 1
+      ), x = c(
+        4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14,
+        15, 16, 17, 18, 19, 20, 21, 22
+      ), xmin = c(
+        3.5, 4.5, 5.5, 6.5,
+        7.5, 8.5, 9.5, 10.5, 11.5, 12.5, 13.5, 14.5, 15.5, 16.5, 17.5,
+        18.5, 19.5, 20.5, 21.5
+      ), xmax = c(
+        4.5, 5.5, 6.5, 7.5, 8.5, 9.5,
+        10.5, 11.5, 12.5, 13.5, 14.5, 15.5, 16.5, 17.5, 18.5, 19.5, 20.5,
+        21.5, 22.5
+      ), density = c(
+        0.0240963855421687, 0.0120481927710843,
+        0.0240963855421687, 0.036144578313253, 0.0481927710843374, 0.0481927710843374,
+        0.0843373493975904, 0.0843373493975904, 0.0240963855421687, 0.072289156626506,
+        0.144578313253012, 0.0963855421686747, 0.0602409638554217, 0.0120481927710843,
+        0.0481927710843374, 0.0481927710843374, 0.0602409638554217, 0.0602409638554217,
+        0.0120481927710843
+      ), ncount = c(
+        0.166666666666667, 0.0833333333333333,
+        0.166666666666667, 0.25, 0.333333333333333, 0.333333333333333,
+        0.583333333333333, 0.583333333333333, 0.166666666666667, 0.5,
+        1, 0.666666666666667, 0.416666666666667, 0.0833333333333333,
+        0.333333333333333, 0.333333333333333, 0.416666666666667, 0.416666666666667,
+        0.0833333333333333
+      ), ndensity = c(
+        0.166666666666667, 0.0833333333333333,
+        0.166666666666667, 0.25, 0.333333333333333, 0.333333333333333,
+        0.583333333333333, 0.583333333333333, 0.166666666666667, 0.5,
+        1, 0.666666666666667, 0.416666666666667, 0.0833333333333333,
+        0.333333333333333, 0.333333333333333, 0.416666666666667, 0.416666666666667,
+        0.0833333333333333
+      ), flipped_aes = c(
+        FALSE, FALSE, FALSE, FALSE,
+        FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE, FALSE,
+        FALSE, FALSE, FALSE, FALSE, FALSE, FALSE
+      ), PANEL = structure(c(
+        1L,
+        1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L,
+        1L, 1L
+      ), .Label = "1", class = "factor"), group = c(
+        -1L, -1L,
+        -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L, -1L,
+        -1L, -1L, -1L, -1L
+      ), ymin = c(
+        0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+        0, 0, 0, 0, 0, 0, 0, 0
+      ), ymax = c(
+        2, 1, 2, 3, 4, 4, 7, 7, 2,
+        6, 12, 8, 5, 1, 4, 4, 5, 5, 1
+      ), colour = c(
+        "black", "black",
+        "black", "black", "black", "black", "black", "black", "black",
+        "black", "black", "black", "black", "black", "black", "black",
+        "black", "black", "black"
+      ), size = c(
+        0.5, 0.5, 0.5, 0.5, 0.5,
+        0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5,
+        0.5
+      ), linetype = c(
+        1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
+        1, 1, 1, 1, 1
+      ), alpha = c(
+        0.7, 0.7, 0.7, 0.7, 0.7, 0.7, 0.7,
+        0.7, 0.7, 0.7, 0.7, 0.7, 0.7, 0.7, 0.7, 0.7, 0.7, 0.7, 0.7
+      )), row.names = c(
+        NA,
+        -19L
+      ), class = "data.frame")
+    )
 
-    # even if binwidth changes mean of the distribution shouldn't change
-    testthat::expect_identical(mean(pb1$data[[2]]$x), mean(pb2$data[[2]]$x))
-    testthat::expect_identical(mean(pb3$data[[2]]$x), mean(pb4$data[[2]]$x))
-    testthat::expect_equal(mean(pb1$data[[2]]$y), 14.02795, tolerance = 0.001)
-    testthat::expect_equal(mean(pb2$data[[2]]$y), 0.008271081, tolerance = 0.001)
-    testthat::expect_equal(mean(pb3$data[[2]]$y), 4.627659, tolerance = 0.001)
-    testthat::expect_equal(mean(pb4$data[[2]]$y), 0.1082654, tolerance = 0.001)
+    expect_equal(
+      pb1$data[[3]],
+      structure(
+        list(
+          xintercept = 13.5674698795181,
+          PANEL = structure(1L, .Label = "1", class = "factor"),
+          group = structure(-1L, n = 1L),
+          colour = "blue",
+          size = 1,
+          linetype = "dashed",
+          alpha = NA
+        ),
+        row.names = c(NA, -1L),
+        class = "data.frame"
+      )
+    )
 
     # annotation
-    testthat::expect_null(pb1$plot$labels$caption, NULL)
-    testthat::expect_null(pb2$plot$labels$caption, NULL)
-    testthat::expect_null(pb3$plot$labels$caption, NULL)
-    testthat::expect_null(pb4$plot$labels$caption, NULL)
+    expect_equal(
+      pb1$plot$labels,
+      list(
+        x = "awake",
+        y = "count",
+        title = NULL,
+        subtitle = NULL,
+        caption = NULL,
+        fill = "count",
+        weight = "weight",
+        xintercept = "xintercept",
+        label = "centrality_df$label[[1]]"
+      )
+    )
   }
 )
 
 # subtitle output --------------------------------------------------
 
-testthat::test_that(
+test_that(
   desc = "subtitle output",
   code = {
-    testthat::skip_on_cran()
+    skip_on_cran()
 
     # should output a list of length 3
     set.seed(123)
@@ -639,8 +559,7 @@ testthat::test_that(
         x = brainwt,
         output = "subtitle",
         type = "np",
-        test.value = 0.25,
-        messages = FALSE
+        test.value = 0.25
       )
 
     set.seed(123)
@@ -650,11 +569,10 @@ testthat::test_that(
         x = brainwt,
         output = "subtitle",
         type = "np",
-        test.value = 0.25,
-        messages = FALSE
+        test.value = 0.25
       )
 
     # tests
-    testthat::expect_identical(p_sub, sub)
+    expect_identical(p_sub, sub)
   }
 )
