@@ -1,9 +1,9 @@
 # one sample proportion test -----------------------------------------
 
-testthat::test_that(
+test_that(
   desc = "checking one sample proportion test",
   code = {
-    testthat::skip_on_cran()
+    skip_on_cran()
 
     # creating the plot
     set.seed(123)
@@ -35,15 +35,16 @@ testthat::test_that(
     # caption
     set.seed(123)
     p_cap <-
-      statsExpressions::bf_contingency_tab(
+      statsExpressions::expr_contingency_tab(
         data = ggplot2::msleep,
+        type = "bayes",
         x = "vore",
         top.text = "From ggplot2 package",
         output = "caption"
       )
 
     # checking geom data
-    testthat::expect_equal(
+    expect_equal(
       pb$data[[1]],
       structure(
         list(
@@ -97,7 +98,7 @@ testthat::test_that(
       )
     )
 
-    testthat::expect_equal(
+    expect_equal(
       pb$data[[2]],
       structure(
         list(
@@ -155,21 +156,21 @@ testthat::test_that(
     )
 
     # checking plot labels
-    testthat::expect_identical(pb$plot$labels$subtitle, p_subtitle)
-    testthat::expect_identical(pb$plot$labels$title, "mammalian sleep")
-    testthat::expect_identical(pb$plot$labels$caption, p_cap)
-    testthat::expect_null(pb$plot$labels$x, NULL)
-    testthat::expect_null(pb$plot$labels$y, NULL)
-    testthat::expect_identical(pb$plot$plot_env$legend.title, "vore")
+    expect_identical(pb$plot$labels$subtitle, p_subtitle)
+    expect_identical(pb$plot$labels$title, "mammalian sleep")
+    expect_identical(pb$plot$labels$caption, p_cap)
+    expect_null(pb$plot$labels$x, NULL)
+    expect_null(pb$plot$labels$y, NULL)
+    expect_identical(pb$plot$plot_env$legend.title, "vore")
   }
 )
 
 # contingency tab ---------------------------------------------------------
 
-testthat::test_that(
+test_that(
   desc = "checking labels with contingency tab",
   code = {
-    testthat::skip_on_cran()
+    skip_on_cran()
 
     # creating the plot
     set.seed(123)
@@ -200,7 +201,7 @@ testthat::test_that(
         y = am
       )
 
-    testthat::expect_s3_class(
+    expect_s3_class(
       suppressWarnings(ggstatsplot::ggpiestats(
         data = mtcars_small,
         y = cyl,
@@ -225,27 +226,28 @@ testthat::test_that(
     # subtitle used
     set.seed(123)
     p_cap <-
-      suppressWarnings(statsExpressions::bf_contingency_tab(
+      suppressWarnings(statsExpressions::expr_contingency_tab(
         data = mtcars,
         x = "am",
         y = "cyl",
+        type = "bayes",
         output = "caption"
       ))
 
 
     # with facets
-    testthat::expect_equal(length(pb$data), 3L)
-    testthat::expect_equal(dim(pb$data[[1]]), c(6L, 14L))
-    testthat::expect_equal(dim(pb$data[[2]]), c(6L, 19L))
-    testthat::expect_equal(dim(pb$data[[3]]), c(3L, 18L))
+    expect_equal(length(pb$data), 3L)
+    expect_equal(dim(pb$data[[1]]), c(6L, 14L))
+    expect_equal(dim(pb$data[[2]]), c(6L, 19L))
+    expect_equal(dim(pb$data[[3]]), c(3L, 18L))
 
     # without facets
-    testthat::expect_equal(length(pb1$data), 2L)
-    testthat::expect_equal(dim(pb1$data[[1]]), c(3L, 14L))
-    testthat::expect_equal(dim(pb1$data[[2]]), c(3L, 19L))
+    expect_equal(length(pb1$data), 2L)
+    expect_equal(dim(pb1$data[[1]]), c(3L, 14L))
+    expect_equal(dim(pb1$data[[2]]), c(3L, 19L))
 
     # check geoms
-    testthat::expect_equal(
+    expect_equal(
       pb$data[[2]]$y,
       c(
         0.636363636363636,
@@ -257,26 +259,26 @@ testthat::test_that(
       ),
       tolerance = 0.001
     )
-    testthat::expect_equal(
+    expect_equal(
       pb1$data[[2]]$y,
       c(0.684210526315789, 0.263157894736842, 0.0789473684210526),
       tolerance = 0.001
     )
 
     # checking plot labels
-    testthat::expect_identical(pb$plot$labels$subtitle, p_subtitle)
-    testthat::expect_identical(pb$plot$labels$caption, p_cap)
-    testthat::expect_null(pb$plot$labels$x, NULL)
-    testthat::expect_null(pb$plot$labels$y, NULL)
-    testthat::expect_identical(pb$plot$guides$fill$title[1], "transmission")
-    testthat::expect_type(pb1$plot$labels$subtitle, "language")
+    expect_identical(pb$plot$labels$subtitle, p_subtitle)
+    expect_identical(pb$plot$labels$caption, p_cap)
+    expect_null(pb$plot$labels$x, NULL)
+    expect_null(pb$plot$labels$y, NULL)
+    expect_identical(pb$plot$guides$fill$title[1], "transmission")
+    expect_type(pb1$plot$labels$subtitle, "language")
 
     # checking labels
-    testthat::expect_identical(
+    expect_identical(
       pb$data[[2]]$label,
       c("8", "3", "3", "4", "2", "12")
     )
-    testthat::expect_identical(
+    expect_identical(
       pb$data[[3]]$label,
       c(
         "list(~chi['gof']^2~(1)==2.27, ~italic(p)=='0.132', ~italic(n)==11)",
@@ -286,7 +288,7 @@ testthat::test_that(
     )
 
     # check if palette changed
-    testthat::expect_identical(
+    expect_identical(
       pb$data[[1]]$fill,
       c(
         "#9A8822FF",
@@ -297,7 +299,7 @@ testthat::test_that(
         "#F5CDB4FF"
       )
     )
-    testthat::expect_identical(
+    expect_identical(
       pb1$data[[1]]$fill,
       c("#1B9E77FF", "#D95F02FF", "#7570B3FF")
     )
@@ -306,10 +308,10 @@ testthat::test_that(
 
 # contingency tab (with counts) ----------------------------------------------
 
-testthat::test_that(
+test_that(
   desc = "checking labels with counts",
   code = {
-    testthat::skip_on_cran()
+    skip_on_cran()
 
     # plot
     set.seed(123)
@@ -347,27 +349,27 @@ testthat::test_that(
       )
 
     # testing everything is okay with data
-    testthat::expect_equal(dim(dat), c(4L, 5L))
-    testthat::expect_equal(dat$perc, c(8.46, 48.38, 91.54, 51.62), tolerance = 1e-3)
-    testthat::expect_equal(dat$Survived[1], "No")
-    testthat::expect_equal(dat$Survived[4], "Yes")
-    testthat::expect_equal(dat$Sex[2], "Female")
-    testthat::expect_equal(dat$Sex[3], "Male")
-    testthat::expect_identical(dat$counts, c(126L, 344L, 1364L, 367L))
+    expect_equal(dim(dat), c(4L, 5L))
+    expect_equal(dat$perc, c(8.46, 48.38, 91.54, 51.62), tolerance = 1e-3)
+    expect_equal(dat$Survived[1], "No")
+    expect_equal(dat$Survived[4], "Yes")
+    expect_equal(dat$Sex[2], "Female")
+    expect_equal(dat$Sex[3], "Male")
+    expect_identical(dat$counts, c(126L, 344L, 1364L, 367L))
 
     # checking plot labels
-    testthat::expect_identical(pb$plot$labels$subtitle, p_subtitle)
-    testthat::expect_null(pb$plot$labels$caption, NULL)
-    testthat::expect_identical(pb$plot$plot_env$legend.title, "Sex")
+    expect_identical(pb$plot$labels$subtitle, p_subtitle)
+    expect_null(pb$plot$labels$caption, NULL)
+    expect_identical(pb$plot$plot_env$legend.title, "Sex")
   }
 )
 
 # mcnemar test ---------------------------------------------------------
 
-testthat::test_that(
+test_that(
   desc = "checking labels with contingency tab (paired)",
   code = {
-    testthat::skip_on_cran()
+    skip_on_cran()
 
     # data
     set.seed(123)
@@ -406,7 +408,7 @@ testthat::test_that(
       )
 
     # checking plot labels
-    testthat::expect_identical(
+    expect_identical(
       pb$plot$labels,
       list(
         x = NULL,
@@ -421,7 +423,7 @@ testthat::test_that(
     )
 
     # labels
-    testthat::expect_identical(
+    expect_identical(
       pb$data[[3]]$label,
       c(
         "list(~chi['gof']^2~(1)==569.62, ~italic(p)=='6.8e-126', ~italic(n)==880)",
@@ -433,10 +435,10 @@ testthat::test_that(
 
 # repelling labels -------------------------------------------------------------
 
-testthat::test_that(
+test_that(
   desc = "repelling labels",
   code = {
-    testthat::skip_on_cran()
+    skip_on_cran()
     set.seed(123)
 
     # data
@@ -492,7 +494,7 @@ testthat::test_that(
     pb <- ggplot2::ggplot_build(p)
 
     # tests
-    testthat::expect_equal(
+    expect_equal(
       pb$data[[2]]$y,
       c(
         0.923951048951049,
@@ -506,7 +508,7 @@ testthat::test_that(
       )
     )
 
-    testthat::expect_equal(
+    expect_equal(
       pb$data[[2]]$ymin,
       c(
         0.847902097902098,
@@ -520,7 +522,7 @@ testthat::test_that(
       )
     )
 
-    testthat::expect_equal(
+    expect_equal(
       pb$data[[2]]$ymax,
       c(
         1,
@@ -538,10 +540,10 @@ testthat::test_that(
 
 # without enough data ---------------------------------------------------------
 
-testthat::test_that(
+test_that(
   desc = "checking if functions work without enough data",
   code = {
-    testthat::skip_on_cran()
+    skip_on_cran()
     set.seed(123)
 
     # creating a dataframe
@@ -552,7 +554,7 @@ testthat::test_that(
       )
 
     # subtitle
-    testthat::expect_null(ggstatsplot::ggpiestats(
+    expect_null(ggstatsplot::ggpiestats(
       data = df,
       x = x,
       output = "subtitle"
@@ -562,10 +564,10 @@ testthat::test_that(
 
 # subtitle output --------------------------------------------------
 
-testthat::test_that(
+test_that(
   desc = "subtitle output",
   code = {
-    testthat::skip_on_cran()
+    skip_on_cran()
 
     set.seed(123)
     df <- dplyr::sample_frac(tbl = forcats::gss_cat, size = 0.1) %>%
@@ -605,16 +607,17 @@ testthat::test_that(
     # caption output
     set.seed(123)
     p_cap_exp <-
-      statsExpressions::bf_contingency_tab(
+      statsExpressions::expr_contingency_tab(
         data = df,
         x = "race",
         y = marital,
+        type = "bayes",
         output = "caption",
         k = 4
       )
 
     # tests
-    testthat::expect_identical(p_sub, stats_output)
-    testthat::expect_identical(p_cap, p_cap_exp)
+    expect_identical(p_sub, stats_output)
+    expect_identical(p_cap, p_cap_exp)
   }
 )
