@@ -1,13 +1,13 @@
 # output: plot ---------------------------------------------------------------
 
-testthat::test_that(
+test_that(
   desc = "grouped_ggcorrmat plots work",
   code = {
-    testthat::skip_on_cran()
+    skip_on_cran()
 
     # with grouping.var missing ---------------------------------------------
 
-    testthat::expect_error(ggstatsplot::grouped_ggcorrmat(iris))
+    expect_error(ggstatsplot::grouped_ggcorrmat(iris))
 
     # with cor.vars specified -----------------------------------------------
 
@@ -20,26 +20,24 @@ testthat::test_that(
 
     # when arguments are entered as bare expressions
     set.seed(123)
-    testthat::expect_true(inherits(
+    expect_true(inherits(
       suppressWarnings(ggstatsplot::grouped_ggcorrmat(
         data = movies_filtered,
         grouping.var = mpaa,
         cor.vars = length:votes,
-        type = "p",
-        messages = FALSE
+        type = "p"
       )),
       what = "gg"
     ))
 
     # when arguments are entered as character
     set.seed(123)
-    testthat::expect_true(inherits(
+    expect_true(inherits(
       suppressWarnings(ggstatsplot::grouped_ggcorrmat(
         data = movies_filtered,
         grouping.var = "mpaa",
         cor.vars = c("length":"votes"),
-        type = "np",
-        messages = FALSE
+        type = "np"
       )),
       what = "gg"
     ))
@@ -48,24 +46,22 @@ testthat::test_that(
 
     # when arguments are entered as bare expressions
     set.seed(123)
-    testthat::expect_true(inherits(
+    expect_true(inherits(
       suppressWarnings(ggstatsplot::grouped_ggcorrmat(
         data = movies_filtered,
         grouping.var = mpaa,
-        type = "p",
-        messages = FALSE
+        type = "p"
       )),
       what = "gg"
     ))
 
     # when arguments are entered as bare expressions
     set.seed(123)
-    testthat::expect_true(inherits(
+    expect_true(inherits(
       suppressWarnings(ggstatsplot::grouped_ggcorrmat(
         data = movies_filtered,
         grouping.var = "mpaa",
-        type = "r",
-        messages = FALSE
+        type = "r"
       )),
       what = "gg"
     ))
@@ -74,10 +70,10 @@ testthat::test_that(
 
 # output: stats ---------------------------------------------------------------
 
-testthat::test_that(
+test_that(
   desc = "grouped_ggcorrmat stats work",
   code = {
-    testthat::skip_on_cran()
+    skip_on_cran()
 
     # without cor.vars specified --------------------------------------------
 
@@ -88,11 +84,10 @@ testthat::test_that(
         data = ggplot2::msleep,
         grouping.var = vore,
         output = "r",
-        k = 3,
-        messages = FALSE
+        k = 3
       )
 
     # testing dataframe
-    testthat::expect_equal(dim(df1), c(60L, 11L))
+    expect_equal(dim(df1), c(60L, 11L))
   }
 )
